@@ -12,14 +12,16 @@ class Fellowship(_ContinuumDataset):
         self,
         dataset_list: List[Type[_ContinuumDataset]],
         data_path: str = "",
+        train: bool = True,
         download: bool = True,
     ):
-        super(Fellowship, self).__init__(data_path, download)
+        super().__init__(data_path, download)
 
-        self.datasets = [dataset(data_path, download) for dataset in dataset_list]
+        self.datasets = [
+            dataset(data_path=data_path, train=train, download=download) for dataset in dataset_list
+        ]
 
-
-    def get_data(self) -> Tuple[np.ndarray, np.ndarray,  np.ndarray]:
+    def get_data(self) -> Tuple[np.ndarray, np.ndarray, np.ndarray]:
         x, y, t = [], [], []
         class_counter = 0
 
@@ -28,7 +30,7 @@ class Fellowship(_ContinuumDataset):
 
             x.append(data[0])
             y.append(data[1] + class_counter)
-            t.append(np.ones(len(data[0])*i))
+            t.append(np.ones(len(data[0]) * i))
 
             class_counter += len(np.unique(data[1]))
 
@@ -41,11 +43,18 @@ class Fellowship(_ContinuumDataset):
 
 class MNISTFellowship(Fellowship):
 
-    def __init__(self, data_path: str = "", download: bool = True) -> None:
-        super(MNISTFellowship, self).__init__([MNIST, FashionMNIST, KMNIST], data_path, download)
+    def __init__(self, data_path: str = "", train: bool = True, download: bool = True) -> None:
+        super().__init__(
+            dataset_list=[MNIST, FashionMNIST, KMNIST],
+            train=train,
+            data_path=data_path,
+            download=download
+        )
 
 
 class CIFARFellowship(Fellowship):
 
-    def __init__(self, data_path: str = "", download: bool = True) -> None:
-        super(CIFARFellowship, self).__init__([CIFAR10, CIFAR100], data_path, download)
+    def __init__(self, data_path: str = "", train: bool = True, download: bool = True) -> None:
+        super().__init__(
+            dataset_list=[CIFAR10, CIFAR100], train=train, data_path=data_path, download=download
+        )
