@@ -38,38 +38,32 @@ class ImageNet100(ImageNet1000):
     test_subset_url = "https://github.com/Continvvm/continuum/releases/download/v0.1/val_100.txt"
 
     def __init__(
-            self,
-            *args,
-            data_subset: Union[Tuple[np.array, np.array], str, None] = None,
-            **kwargs
+        self, *args, data_subset: Union[Tuple[np.array, np.array], str, None] = None, **kwargs
     ):
         self.data_subset = data_subset
-        super(ImageNet100, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def _download(self):
-        super(ImageNet100, self)._download()
+        super()._download()
 
         filename = "val_100.txt"
-        self.subset_url = test_subset_url
+        self.subset_url = self.test_subset_url
         if self.train:
             filename = "train_100.txt"
-            self.subset_url = train_subset_url
+            self.subset_url = self.train_subset_url
 
         if self.data_subset is None:
             self.data_subset = os.path.join(self.data_folder, filename)
             download(self.subset_url, self.data_folder)
 
-    def init(self, train: bool) -> Tuple[np.ndarray, np.ndarray, Union[np.ndarray, None]]:
-        data = self._parse_subset(
-            self.data_subset, train=train
-        )  # type: ignore
-
+    def get_data(self) -> Tuple[np.ndarray, np.ndarray, Union[np.ndarray, None]]:
+        data = self._parse_subset(self.data_subset, train=self.train)  # type: ignore
         return (*data, None)
 
     def _parse_subset(
-            self,
-            subset: Union[Tuple[np.array, np.array], str, None],
-            train: bool = True
+        self,
+        subset: Union[Tuple[np.array, np.array], str, None],
+        train: bool = True
     ) -> Tuple[np.array, np.array]:
         if isinstance(subset, str):
             x, y = [], []
